rm(list=ls())

#######################################
# stuff i need
library("depmixS4")
library("foreign")
library("zoo")
library("dplyr")
library("ggplot2")
library("gridExtra")
library("lmtest")
library("cowplot")


#######################################
# load + transform data
D <- read.dta("Haushofer_data.dta")
D$yearmon <- as.yearmon(paste(substr(D$date, 1, 4), "-", substr(D$date, 5, 6), sep=""))
D$yearqtr <- as.yearqtr(D$yearmon)
D$month <- as.numeric(substr(D$date, 5,6))
D$day <- as.numeric(substr(D$date, 7,8))
D$year <- as.numeric(substr(D$date, 1,4))
D$Jan1 <- D$day==1 & D$month == "1"
D$ts <- 1:dim(D)[1]

# monthly data
Dm <- D %>%
  dplyr::filter(year > 2002) %>%
  dplyr::select(qs, yearmon) %>%
  group_by(yearmon) %>%
  summarize(qsmean = mean(qs, na.rm=T),
            qssum = sum(qs,na.rm=T))
Dm$ts <- 1:dim(Dm)[1]
Dm <- Dm %>% filter(!is.nan(qsmean))
Dm$Jan <- substr(Dm$yearmon, 1,3) == "Jan"
Dm$year <- as.numeric(substr(Dm$yearmon, 5,8))
Dm$qsl <- log(Dm$qssum + 1)

# detrend data
lfit <- glm(qsl ~ ts + I(ts^2), data=Dm)
Dm$qsldt <- Dm$qsl - lfit$fitted.values + lfit$fitted.values[1]

#######################################
# graph the transformation of the data

datagraph1 <- ggplot(D[!is.na(D$qs),], aes(x=ts, y=qs)) + geom_point() + 
  scale_x_continuous(breaks = which(D$Jan1), labels = D$year[D$Jan1]) + 
  ylab(" ") + 
  xlab("Time") + theme_bw(14) + 
  theme(axis.text.x = element_text(angle=90, vjust=1)) +
  ggtitle("Daily counts of rockets")

datagraph2 <- ggplot(Dm, aes(x=ts, y=qssum)) + geom_point(size=2.2) + 
  scale_x_continuous(breaks = which(Dm$Jan), labels = Dm$year[Dm$Jan]) + 
  ylab(" ") + 
  xlab("Time") + theme_bw(14) + 
  theme(axis.text.x = element_text(angle=90, vjust=1)) + 
  ggtitle("Monthly counts of rockets")

datagraph3 <- ggplot(Dm, aes(x=ts, y=qsl)) + geom_point(size=2.2) + 
  scale_x_continuous(breaks = which(Dm$Jan), labels = Dm$year[Dm$Jan]) + 
  ylab(" ") + 
  xlab("Time") + theme_bw(14) + 
  theme(axis.text.x = element_text(angle=90, vjust=1)) + 
  ggtitle("Logged monthly counts of rockets")

datagraph4 <- ggplot(Dm, aes(x=ts, y=qsldt)) + geom_point(size=2.2) + 
  scale_x_continuous(breaks = which(Dm$Jan), labels = Dm$year[Dm$Jan]) + 
  ylab(" ") + 
  xlab("Time") + theme_bw(14) + 
  theme(axis.text.x = element_text(angle=90, vjust=1))+ 
  ggtitle("Detrended logged monthly counts of rockets")

pdf("transformationGraphs.pdf", height=11, width=8.5)
grid.arrange(datagraph1, 
             datagraph2,
             datagraph3,
             datagraph4,
             ncol=1, nrow =4)
dev.off()
embed_fonts("transformationGraphs.pdf")
save(Dm, file = "transformed_data.Rdata")



