rm(list=ls())

#######################################
# stuff i need
library("depmixS4")
library("foreign")
library("zoo")
library("dplyr")
library("ggplot2")
library("gridExtra")
library("fontcm")
library("extrafont")
library("lmtest")
library("cowplot")
library("aods3")
loadfonts(quiet = T)

#######################################
# load data from step 1
load("transformed_data.Rdata")


#######################################
# estimate model
# NOTE: choosing instart = c(1,0) results in a lower log-likelihood.
# NOTE: choosing instart = c(0.5,0.5) results in same results as those reported here.

set.seed(101)
mod <- depmix(qsldt ~ 1, data = Dm, nstates=2, instart = c(0,1)) 
fm <- fit(mod, emc=em.control(random.start=T, crit = "absolute", tol = 1e-10))


#######################################
# TABLE 1
CoefsAndSEs <- standardError(fm)[,c(1,3)]

# coefficents and starndard errors:
round(CoefsAndSEs[c(4,5,7:10),], digits = 3)

# number of observations 
length(Dm$qsldt)

# log likelihood
fm


#######################################
# compute quantities of interest:
# these are used in text below table 1

estab <- getpars(fm)[c(4,5)]

# strategies
sT0hat <- estab[1]/(1-estab[2])
sG1hat <- estab[2]

# invardist
pi1hat <- sT0hat*(1-sG1hat)/(sT0hat + sG1hat - sT0hat*sG1hat)

# expected periods between attacks
EXhat <- (sT0hat + sG1hat - sT0hat*sG1hat)/(sT0hat*sG1hat)


#######################################
# Z-test
# mentioned in empirical section

invarDist <- function(est){
   sT0 <- est[1]/(1-est[2])
   sG1 <- est[2]
   pi1 <- sT0*(1-sG1)/(sT0 + sG1 - sT0*sG1)
   return(pi1)
}
 
 invarDistj <- function(est){
   grad1 <- est[2]/((est[1] + est[2])^2)
   grad2 <- -est[1]/((est[1] + est[2])^2)
   return(cbind(grad1, grad2))
}
 

# compute standard error of pi(1) using delta method: 
hmmVcov <- vcov(fm)
Vcovab <- vcov(fm)$vcov[c(2,3),c(2,3)] 
pi1hat.se <-  sqrt(invarDistj(estab) %*% Vcovab %*% t(invarDistj(estab)))

# compute p value:
# here H_0 is pi(1) >= 0.99
pnorm((pi1hat - 0.99)/pi1hat.se)


# compute p value:
# here H_0 is pi(1) <= 0.01
1-pnorm((pi1hat - 0.01)/pi1hat.se)

#######################################
# SAVE RESULTS
# results are used for figures and marginal effects
save(fm, sT0hat, sG1hat, pi1hat, EXhat, file="hmm_results.rdata")



