rm(list=ls())

#######################################
# stuff i need
library("depmixS4")
library("foreign")
library("zoo")
library("dplyr")
library("ggplot2")
library("gridExtra")
library("lmtest")
library("cowplot")
library("aods3")


#######################################
# load results from Step 2:
load("hmm_results.rdata")


#######################################
# functions i need
kappaT <- function(dT){return((1-sG1hat)/(1-dT*(1-sG1hat)))}
kappaG <- function(dG){return((1-dG*(1-sT0hat))^(-1))}

SigmaG1 <- function(kT, dT){return((1-kT*(1-dT))/(1+dT*kT))} 
SigmaT0 <- function(kG, dG){return((1-kG*(1-dG))/(kG*dG))} 
piHi <- function(sT0, sG1){return(sT0*(1-sG1)/(sT0 + sG1 - sT0*sG1))}
Eattack <- function(sT0, sG1){return((sT0 + sG1 - sT0*sG1)/(sT0*sG1))}


#######################################
# BOUNDS ON KAPPA
kappaG(c(0,1))
kappaT(c(0,1))


#######################################
# counterfactuals
Deltas <- c(0.8, 0.99)

CF_kappaT = data.frame(
  kT=rep(seq(from = 1/20, to = 1.5*kappaT(1), length.out=100),2),
  dT = rep(Deltas, each=100))
CF_kappaT$sG1 <- ifelse(CF_kappaT$kT < 1/(1-CF_kappaT$dT),
                        SigmaG1(CF_kappaT$kT, CF_kappaT$dT),
                        1)
CF_kappaT$piHi <- ifelse(CF_kappaT$kT < 1/(1-CF_kappaT$dT),
                         piHi(sT0hat, CF_kappaT$sG1), 0)
CF_kappaT$Eattack <- ifelse(CF_kappaT$kT < 1/(1-CF_kappaT$dT),
                            Eattack(sT0hat, CF_kappaT$sG1), 
                            NA)

CF_kappaG = data.frame(
  kG=rep(seq(from = 1+1/20, to = 2*kappaG(1), length.out=100),2),
  dG = rep(Deltas, each=100))        

CF_kappaG$sT0 <- pmax(SigmaT0(CF_kappaG$kG, CF_kappaG$dG),0)
CF_kappaG$piHi <- ifelse(CF_kappaG$kG < 1/(1-CF_kappaG$dG),
                         piHi(CF_kappaG$sT0, sG1hat), 1)
CF_kappaG$Eattack <- ifelse(CF_kappaG$kG < 1/(1-CF_kappaG$dG),
                            Eattack(CF_kappaG$sT0, sG1hat),
                            NA)

#######################################
# GRAPHS: Code to make figures 1 and 2


#######################################
# graph the gpvernments counterfactuals

mysize=2.5
themesize=11
legendsize=3
impatient = "orangered2"

pCFG_st0 <- ggplot(CF_kappaG, 
                   aes(x=kG, y=sT0, 
                       group=as.factor(dG), 
                       color=as.factor(dG),
                       shape=as.factor(dG))) + 
  geom_point() + theme_bw(themesize) + 
  ylab(expression(paste("Terrorist's prob. of investing, ", sigma[T](0)))) + 
  xlab(expression(paste("Government's cost of attacking, ", kappa[G]))) +
  geom_vline(xintercept = kappaG(0.99), color = "navyblue", alpha=0.55) +
  geom_vline(xintercept = kappaG(0.80), color = impatient, alpha=0.55) + 
  geom_hline(yintercept = sT0hat, linetype = "dashed", alpha=0.75) +
  scale_color_manual(values=c(impatient, "navyblue"),
                     name=expression(paste("Discount Factor, ", delta[G],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) + 
  scale_shape_manual(values=c(16,17),
                     name=expression(paste("Discount Factor, ", delta[G],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) +
  guides(colour = guide_legend(override.aes = list(size=legendsize))) + 
  annotate('text', x = 1.16, y = 0.35, label = "delta[G]==0.8",parse = TRUE, size=mysize) + 
  annotate('text', x = 1.39, y = 0.85, label = "delta[G]==0.99",parse = TRUE, size=mysize) + 
  theme(legend.position="top", axis.title.x=element_blank()) 


pCFG_pihi <- ggplot(CF_kappaG, 
                    aes(x=kG, y=piHi, 
                        group=as.factor(dG), 
                        color=as.factor(dG),
                        shape=as.factor(dG))) + 
  geom_point() + theme_bw(themesize) + 
  ylab(expression(paste("Prob. of high-capacity terrorism, ", pi^sigma,"",(1)))) + 
  xlab(expression(paste("Government's cost of attacking, ", kappa[G]))) +
  geom_hline(yintercept = piHi(sT0hat, sG1hat), linetype = "dashed", alpha=0.75) +
  geom_vline(xintercept = kappaG(0.99), color = "navyblue", alpha=0.55) +
  geom_vline(xintercept = kappaG(0.80), color = impatient, alpha=0.55) + 
  scale_color_manual(values=c(impatient, "navyblue"),
                     name=expression(paste("Discount Factor, ", delta[i],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) + 
  scale_shape_manual(values=c(16,17),
                     name=expression(paste("Discount Factor, ", delta[i],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) +
  guides(colour = guide_legend(override.aes = list(size=legendsize))) + 
  annotate('text', x = 1.16, y = 0.89, label = "delta[G]==0.8",parse = TRUE, size=mysize) + 
  annotate('text', x = 1.39, y = 0.81, label = "delta[G]==0.99",parse = TRUE, size=mysize) +
  theme(legend.position="none", axis.title.x=element_blank()) 


pCFG_ex <- ggplot(CF_kappaG, 
                  aes(x=kG, y=Eattack, 
                      group=as.factor(dG), 
                      color=as.factor(dG),
                      shape=as.factor(dG))) + 
  geom_point() + theme_bw(themesize) + 
  ylab(expression(paste("Expected time between attacks, E[X|", sigma,"]"))) + 
  xlab(expression(paste("Government's cost of attacking, ", kappa[G]))) +
  geom_vline(xintercept = kappaG(0.99), color = "navyblue", alpha=0.55) +
  geom_vline(xintercept = kappaG(0.80), color = impatient, alpha=0.55) + 
  geom_hline(yintercept = Eattack(sT0hat, sG1hat), linetype = "dashed", alpha=0.75) +
  scale_color_manual(values=c(impatient, "navyblue"),
                     name=expression(paste("Discount Factor, ", delta[i],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) + 
  scale_shape_manual(values=c(16,17),
                     name=expression(paste("Discount Factor, ", delta[i],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) +
  guides(colour = guide_legend(override.aes = list(size=legendsize))) + 
  annotate('text', x = 1.16, y = 19.5, label = "delta[G]==0.8",parse = TRUE, size=mysize) + 
  annotate('text', x = 1.39, y = 18.5, label = "delta[G]==0.99",parse = TRUE, size=mysize) +
  theme(legend.position="none")


pdf("counterfactual_kappaG.pdf", height=9, width=6)

plot_grid(pCFG_st0,
          pCFG_pihi,
          pCFG_ex,
          align="v", nrow=3, rel_heights = c(7.625, 6.503, 6.872))
dev.off()




#######################################
# graph the terrorists counterfactuals

adjust = 1.10

pCFT_sg1 <- ggplot(CF_kappaT, 
                   aes(x=kT, y=sG1, 
                       group=as.factor(dT), 
                       color=as.factor(dT),
                       shape=as.factor(dT))) + 
  geom_point() + theme_bw(themesize) + 
  ylab(expression(paste("Government's prob. of attacking, ", sigma[G](1)))) + 
  #theme(axis.title.y = element_text(angle = 0)) +
  xlab(expression(paste("Terrorists's cost of investing, ", kappa[T]))) +
  geom_vline(xintercept = kappaT(0.99), color = "navyblue", alpha=0.55) +
  geom_vline(xintercept = kappaT(0.80), color = impatient, alpha=0.55) + 
  geom_hline(yintercept = sG1hat, linetype = "dashed", alpha=0.75) +
  scale_color_manual(values=c(impatient, "navyblue"),
                     name=expression(paste("Discount Factor, ", delta[T],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) + 
  scale_shape_manual(values=c(16,17),
                     name=expression(paste("Discount Factor, ", delta[T],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) +
  guides(colour = guide_legend(override.aes = list(size=legendsize))) + 
  annotate('text', x = 16.2, y = 0.15, label = "delta[T]==0.99",parse = TRUE, size=mysize) + 
  annotate('text', x = kappaT(0.8)-adjust, y = 0.535, label = "delta[T]==0.8",parse = TRUE, size=mysize) + 
  theme(legend.position="top", axis.title.x=element_blank()) 


pCFT_pihi <- ggplot(CF_kappaT, 
                    aes(x=kT, y=piHi, 
                        group=as.factor(dT), 
                        color=as.factor(dT),
                        shape=as.factor(dT))) + 
  geom_point() + theme_bw(themesize) + 
  ylab(expression(paste("Prob. of high-capacity terrorism, ", pi^sigma,"",(1)))) + 
  xlab(expression(paste("Terrorists's cost of investing, ", kappa[T]))) +
  geom_vline(xintercept = kappaT(0.99), color = "navyblue", alpha=0.55) +
  geom_vline(xintercept = kappaT(0.80), color = impatient, alpha=0.55) + 
  geom_hline(yintercept = piHi(sT0hat, sG1hat), linetype = "dashed", alpha=0.75) +
  scale_color_manual(values=c(impatient, "navyblue"),
                     name=expression(paste("Discount Factor, ", delta[T],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) + 
  scale_shape_manual(values=c(16,17),
                     name=expression(paste("Discount Factor, ", delta[T],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) +
  guides(colour = guide_legend(override.aes = list(size=legendsize))) + 
  annotate('text', x = 16.2, y = 0.6625, label = "delta[T]==0.99",parse = TRUE, size=mysize) + 
  annotate('text', x = kappaT(0.80) - adjust, y = 0.35, label = "delta[T]==0.8",parse = TRUE, size=mysize) + 
  theme(legend.position="none", axis.title.x=element_blank()) 


pCFT_ex <- ggplot(CF_kappaT, 
                  aes(x=kT, y=Eattack, 
                      group=as.factor(dT), 
                      color=as.factor(dT),
                      shape=as.factor(dT))) + 
  geom_point() + theme_bw(themesize) + 
  ylab(expression(paste("Expected time between attacks, E[X|", sigma,"]"))) + 
  xlab(expression(paste("Terrorists's cost of investing, ", kappa[T]))) +
  geom_hline(yintercept = Eattack(sT0hat, sG1hat), linetype = "dashed", alpha=0.75) +
  geom_vline(xintercept = kappaT(0.99), color = "navyblue", alpha=0.55) +
  geom_vline(xintercept = kappaT(0.80), color = impatient, alpha=0.55) + 
  scale_color_manual(values=c(impatient, "navyblue"),
                     name=expression(paste("Discount Factor, ", delta[T],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) + 
  scale_shape_manual(values=c(16,17),
                     name=expression(paste("Discount Factor, ", delta[T],":")),
                     breaks=c("0.8", "0.99"),
                     labels=c("0.80", "0.99")) +
  guides(colour = guide_legend(override.aes = list(size=legendsize))) + 
  annotate('text', x = 16.2, y = 14, label = "delta[T]==0.99",parse = TRUE, size=mysize) + 
  annotate('text', x = kappaT(0.8)-adjust, y = 30, label = "delta[T]==0.8",parse = TRUE, size=mysize) +
  theme(legend.position="none") + ylim(0, 60)


pdf("counterfactual_kappaT.pdf", height=9, width=6)
plot_grid(pCFT_sg1, 
          pCFT_pihi,
          pCFT_ex,
          align="v", nrow=3, rel_heights = c(7.625, 6.503, 6.872))
dev.off()



