rm(list=ls())

#######################################
# stuff i need
library("depmixS4")
library("foreign")
library("zoo")
library("dplyr")
library("ggplot2")
library("gridExtra")
library("lmtest")
library("cowplot")
library("aods3")


#######################################
# load results from Step 2:
load("hmm_results.rdata")


#######################################
# functions i need
kappaT <- function(dT){return((1-sG1hat)/(1-dT*(1-sG1hat)))}
kappaG <- function(dG){return((1-dG*(1-sT0hat))^(-1))}

SigmaG1 <- function(kT, dT){return((1-kT*(1-dT))/(1+dT*kT))} 
SigmaT0 <- function(kG, dG){return((1-kG*(1-dG))/(kG*dG))} 
piHi <- function(sT0, sG1){return(sT0*(1-sG1)/(sT0 + sG1 - sT0*sG1))}
Eattack <- function(sT0, sG1){return((sT0 + sG1 - sT0*sG1)/(sT0*sG1))}


#######################################
# SUBSTANTIVE EFFECTS mentioned in text below figures 1 and 2

# increase kappa_G by 10\%
# first two should be close to a 1% decrease
# first two should be close to a 1% increase

Int <- piHi(SigmaT0(kappaG(0.8), 0.80), sG1hat)
Fin <- piHi(SigmaT0(kappaG(0.8)*1.1, 0.80), sG1hat)
round(100*((Fin - Int)/Int), digits = 2)
 
Int <- piHi(SigmaT0(kappaG(0.99), 0.99), sG1hat)
Fin <- piHi(SigmaT0(kappaG(0.99)*1.1, 0.99), sG1hat)
round(100*((Fin - Int)/Int), digits = 2)

Int <- Eattack(SigmaT0(kappaG(0.8), 0.80), sG1hat)
Fin <- Eattack(SigmaT0(kappaG(0.8)*1.1, 0.80), sG1hat)
round(100*((Fin - Int)/Int), digits = 2)

Int <- Eattack(SigmaT0(kappaG(0.99), 0.99), sG1hat)
Fin <- Eattack(SigmaT0(kappaG(0.99)*1.1, 0.99), sG1hat)
round(100*((Fin - Int)/Int), digits = 2)


# increase kappa_T by 10\%
# first two should be close to a 3% and 1% decrease
# second should be close to a 31% and 10% decrease

Int <-  piHi(sT0hat,  SigmaG1(kappaT(0.8), 0.8))
Fin <-  piHi(sT0hat,  SigmaG1(kappaT(0.8)*0.9, 0.8))
round(100*((Fin - Int)/Int), digits = 2)
 
Int <-  piHi(sT0hat,  SigmaG1(kappaT(0.99), 0.99))
Fin <-  piHi(sT0hat,  SigmaG1(kappaT(0.99)*0.9, 0.99))
round(100*((Fin - Int)/Int), digits = 2)

Int <-  Eattack(sT0hat,  SigmaG1(kappaT(0.8), 0.8))
Fin <-  Eattack(sT0hat,  SigmaG1(kappaT(0.8)*0.9, 0.8))
round(100*((Fin - Int)/Int), digits = 2)

Int <-  Eattack(sT0hat,  SigmaG1(kappaT(0.99), 0.99))
Fin <-  Eattack(sT0hat,  SigmaG1(kappaT(0.99)*0.9, 0.99))
round(100*((Fin - Int)/Int), digits = 2)


#######################################
# MARGINAL EFFECTS: Appendix F

DktSigmaG1 <- function(kT, dT){return(-1/((1+dT*kT)^2))} 
DkgSigmaT0 <- function(kG, dG){return(-1/((kG^2)*dG))}

Dst0piHi <- function(sT0, sG1){return(sG1*(1-sG1)/((sT0 + sG1 - sT0*sG1)^2))}
Dsg1piHi <- function(sT0, sG1){return(-sT0/((sT0 + sG1 - sT0*sG1)^2))}

Dst0Eattack <- function(sT0, sG1){return(-1/(sT0^2))}
Dsg1Eattack <- function(sT0, sG1){return(-1/(sG1^2))}


c1 <- c(DkgSigmaT0(kappaG(0.8),0.8), DkgSigmaT0(kappaG(0.99),0.99), NA, NA)
c2 <- c(NA, NA, DktSigmaG1(kappaT(0.8),0.8), DktSigmaG1(kappaT(0.99),0.99))

c3 <- c(Dst0piHi(SigmaT0(kappaG(0.8), 0.8), sG1hat) * DkgSigmaT0(kappaG(0.8),0.8),
        Dst0piHi(SigmaT0(kappaG(0.99), 0.99), sG1hat) * DkgSigmaT0(kappaG(0.99),0.99),
        Dsg1piHi(sT0hat, SigmaG1(kappaT(0.8), 0.8)) * DktSigmaG1(kappaT(0.8),0.8),
        Dsg1piHi(sT0hat, SigmaG1(kappaT(0.99), 0.99)) * DktSigmaG1(kappaT(0.99),0.99))

c4 <- c(Dst0Eattack(SigmaT0(kappaG(0.8), 0.8), sG1hat) * DkgSigmaT0(kappaG(0.8),0.8),
        Dst0Eattack(SigmaT0(kappaG(0.99), 0.99), sG1hat) * DkgSigmaT0(kappaG(0.99),0.99),
        Dsg1Eattack(sT0hat, SigmaG1(kappaT(0.8), 0.8)) * DktSigmaG1(kappaT(0.8),0.8),
        Dsg1Eattack(sT0hat, SigmaG1(kappaT(0.99), 0.99)) * DktSigmaG1(kappaT(0.99),0.99))

# table 2
round(cbind(c1, c2, c3, c4), digits = 2)

